SignerPublicKey

Struct SignerPublicKey 

pub struct SignerPublicKey {
    pub ident: Scalar,
    /* private fields */
}
A signer’s public key.

This structure contains the public key of a given signer. It includes the signer’s identifier. It does NOT include the group public key.

Fields

ident: Scalar

Signer identifier

Implementations

Source

impl SignerPublicKey

pub const ENC_LEN: usize = 114usize

Signer’s public key encoded length (in bytes).

pub fn encode(self) -> [u8; 114]

Encodes this public key into bytes.

pub fn decode(buf: &[u8]) -> Option<Self>

Decodes this public key from bytes.

The process fails (i.e. returns None) if the source slice does not have a proper length or does not contain properly canonical encodings of the share identifier and signer’s public key.

pub fn verify_signature_share( self, sig_share: SignatureShare, commitment_list: &[Commitment], group_pk: GroupPublicKey, msg: &[u8], ) -> bool

Verifies a signature share relatively to this signer’s public key, for a given signature generation process.

This function can be used by the coordinator to check that the signer computed its signature share properly. It is implictly called by Coordinator::assemble_signature().