pub struct SignerPublicKey {
pub ident: Scalar,
/* private fields */
}Expand description
A signer’s public key.
This structure contains the public key of a given signer. It includes the signer’s identifier. It does NOT include the group public key.
Fields
ident: ScalarSigner identifier
Implementations
Sourceimpl SignerPublicKey
impl SignerPublicKey
Sourcepub fn decode(buf: &[u8]) -> Option<Self>
pub fn decode(buf: &[u8]) -> Option<Self>
Decodes this public key from bytes.
The process fails (i.e. returns None) if the source slice
does not have a proper length or does not contain properly
canonical encodings of the share identifier and signer’s
public key.
Verifies a signature share relatively to this signer’s public key, for a given signature generation process.
This function can be used by the coordinator to check that the
signer computed its signature share properly. It is implictly
called by Coordinator::assemble_signature().